__title__ = "advent-of-code-ocr"
__description__ = "Convert Advent of Code ASCII art"
__version__ = "0.2.0"
__author__ = "Ben Soyka"
__author_email__ = "bensoyka@icloud.com"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2020-present Benjamin Soyka"



from itertools import groupby

import numpy as np

from .characters import ALPHABET_6


def convert_6(input_text: str, *, fill_pixel: str = "#", empty_pixel: str = "."):
    input_text = input_text.replace(fill_pixel, "1").replace(empty_pixel, "0")

    array = np.array([[int(char) for char in row] for row in input_text.split("\n")])

    rows, cols = array.shape

    if rows != 6:
        raise ValueError("incorrect number of rows (expected 6)")

    indices = [
        list(g) for k, g in groupby(range(cols), lambda x: (x + 1) % 5 != 0) if k
    ]

    result = ""

    for index in indices:
        string = "\n".join(
            ["".join([str(char) for char in row]) for row in array[:, index]]
        )
        string = string.replace("0", ".").replace("1", "#")

        letter = ALPHABET_6[string]
        result += letter

    return result



from pathlib import Path

from setuptools import setup

here = Path(__file__).parent.resolve()

readme = (here / "README.md").read_text()

about = {}
exec((here / "advent_of_code_ocr" / "__version__.py").read_text(), about)

setup(
    name=about["__title__"],
    description=about["__description__"],
    version=about["__version__"],
    long_description=readme,
    long_description_content_type="text/markdown",
    author=about["__author__"],
    author_email=about["__author_email__"],
    license=about["__license__"],
    packages=["advent_of_code_ocr"],
    install_requires=["numpy==1.19.4"],
    url="https://github.com/bsoyka/advent-of-code-ocr",
    project_urls={
        "Bug Tracker": "https://github.com/bsoyka/advent-of-code-ocr/issues",
        "Source Code": "https://github.com/bsoyka/advent-of-code-ocr",
    },
)
